@@ -1,10 +1,9 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
-#include <gpaste-client.h>
 #include <gpaste-util.h>
 
 #include <getopt.h>
@@ -19,6 +18,7 @@ typedef struct {
     gboolean      version;
     gboolean      oneline;
     gboolean      raw;
+    gboolean      reverse;
     gboolean      zero;
     const gchar  *decoration;
     const gchar  *separator;
@@ -37,15 +37,16 @@ parse_cmdline (int     *argc,
         { "decoration", required_argument, NULL,  'd'  },
         { "help",       no_argument,       NULL,  'h'  },
         { "oneline",    no_argument,       NULL,  'o'  },
-        { "raw"    ,    no_argument,       NULL,  'r'  },
-        { "separator" , required_argument, NULL,  's'  },
+        { "raw",        no_argument,       NULL,  'r'  },
+        { "reverse",    no_argument,       NULL,  'e'  },
+        { "separator",  required_argument, NULL,  's'  },
         { "version",    no_argument,       NULL,  'v'  },
         { "zero",       no_argument,       NULL,  'z'  },
         { NULL,         no_argument,       NULL,  '\0' }
     };
     gint64 c;
 
-    while ((c = getopt_long(*argc, *argv, "d:hors:vz", long_options, NULL)) != -1)
+    while ((c = getopt_long(*argc, *argv, "d:hores:vz", long_options, NULL)) != -1)
     {
         switch (c)
         {
@@ -61,6 +62,9 @@ parse_cmdline (int     *argc,
         case 'r':
             ctx->raw = TRUE;
             break;
+        case 'e':
+            ctx->reverse = TRUE;
+            break;
         case 's':
             ctx->separator = optarg;
             break;
@@ -201,16 +205,6 @@ show_help (void)
     printf ("  %s settings: %s\n", progname, _("launch the configuration tool"));
     /* Translators: help for gpaste ui */
     printf ("  %s ui: %s\n", progname, _("launch the graphical tool"));
-    if (g_paste_util_has_applet ())
-    {
-        /* Translators: help for gpaste applet */
-        printf ("  %s applet: %s\n", progname, _("launch the applet"));
-    }
-    if (g_paste_util_has_unity ())
-    {
-        /* Translators: help for gpaste app-indicator */
-        printf ("  %s app-indicator: %s\n", progname, _("launch the unity application indicator"));
-    }
     /* Translators: help for gpaste show-history */
     printf ("  %s show-history: %s\n", progname, _("make the applet or extension display the history"));
     /* Translators: help for gpaste upload */
@@ -229,9 +223,11 @@ show_help (void)
     printf("\n");
     /* Translators: help for --oneline */
     printf("  --oneline: %s\n", _("display each item on only one line"));
-    /* Translators: help for --oneline */
+    /* Translators: help for --raw */
     printf("  --raw: %s\n", _("display each item raw (without line numbers)"));
-    /* Translators: help for --oneline */
+    /* Translators: help for --reverse */
+    printf("  --reverse: %s\n", _("display the items in reverse order"));
+    /* Translators: help for --zero */
     printf("  --zero: %s\n", _("use a NUL character instead of a new line betweean each item"));
 
     printf("\n");
@@ -293,10 +289,10 @@ g_paste_history (Context *ctx,
     if (*error)
         return EXIT_FAILURE;
 
-    guint64 i = 0;
+    guint length = g_strv_length (history);
 
-    for (GStrv h = history; *h; ++h)
-        print_history_line (*h, i++, ctx);
+    for (guint64 i = (ctx->reverse ? (length - 1) : 0); ctx->reverse ? i != ((guint64) -1) : i < length; i += (ctx->reverse ? -1 : 1))
+        print_history_line (history[i], i, ctx);
 
     return EXIT_SUCCESS;
 }
@@ -471,20 +467,6 @@ g_paste_ui (Context *ctx   G_GNUC_UNUSED,
     return spawn ("Ui");
 }
 
-static gint
-g_paste_applet (Context *ctx   G_GNUC_UNUSED,
-                GError **error G_GNUC_UNUSED)
-{
-    return (g_paste_util_has_applet ()) ? spawn ("Applet") : -1;
-}
-
-static gint
-g_paste_app_indicator (Context *ctx   G_GNUC_UNUSED,
-                       GError **error G_GNUC_UNUSED)
-{
-    return (g_paste_util_has_unity ()) ? spawn ("AppIndicator") : -1;
-}
-
 static gint
 g_paste_add (Context *ctx,
              GError **error)
@@ -730,10 +712,8 @@ g_paste_dispatch (gint         argc,
         { 1, "q",               0,        TRUE,  g_paste_stop            },
         { 1, "quit",            0,        TRUE,  g_paste_stop            },
         { 1, "ui",              0,        FALSE, g_paste_ui              },
-        { 1, "applet",          0,        FALSE, g_paste_applet          },
-        { 1, "app-indicator",   0,        FALSE, g_paste_app_indicator   },
-        { 2, "a",               0,        TRUE,  g_paste_add             },
-        { 2, "add",             0,        TRUE,  g_paste_add             },
+        { 1, "a",               1,        TRUE,  g_paste_add             },
+        { 1, "add",             1,        TRUE,  g_paste_add             },
         { 2, "ap",              1,        TRUE,  g_paste_add_password    },
         { 2, "add-password",    1,        TRUE,  g_paste_add_password    },
         { 2, "bh",              1,        TRUE,  g_paste_backup_history  },
@@ -797,7 +777,7 @@ main (gint argc, gchar *argv[])
     g_set_prgname (argv[0]);
 
     g_autoptr (GError) error = NULL;
-    Context ctx = { NULL, 0, NULL, NULL, FALSE, FALSE, FALSE, FALSE, FALSE, NULL, NULL };
+    Context ctx = { NULL, 0, NULL, NULL, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, NULL, NULL };
     gint status;
 
     if (parse_cmdline (&argc, &argv, &ctx))
