@@ -1,20 +1,15 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2019, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
-/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
 
 const Gettext = imports.gettext;
-const Lang = imports.lang;
 
 const PanelMenu = imports.ui.panelMenu;
 const PopupMenu = imports.ui.popupMenu;
 
-const Clutter = imports.gi.Clutter;
-const GLib = imports.gi.GLib;
-
-const GPaste = imports.gi.GPaste;
+const { Clutter, GObject, GLib, GPaste, St } = imports.gi;
 
 const _ = Gettext.domain('GPaste').gettext;
 
@@ -31,15 +26,13 @@ const StateSwitch = Me.imports.stateSwitch;
 const StatusIcon = Me.imports.statusIcon;
 const UiItem = Me.imports.uiItem;
 
-var GPasteIndicator = new Lang.Class({
-    Name: 'GPasteIndicator',
-    Extends: PanelMenu.Button,
-
-    _init: function() {
-        this.parent(0.0, "GPaste");
+var GPasteIndicator = GObject.registerClass(
+class GPasteIndicator extends PanelMenu.Button {
+    _init() {
+        super._init(0.0, "GPaste");
 
         this._statusIcon = new StatusIcon.GPasteStatusIcon();
-        this.actor.add_child(this._statusIcon.actor);
+        this.add_child(this._statusIcon);
 
         this._settings = new GPaste.Settings();
 
@@ -58,6 +51,7 @@ var GPasteIndicator = new Lang.Class({
 
         this._settingsSizeChangedId = this._settings.connect('changed::element-size', this._resetElementSize.bind(this));
         this._resetElementSize();
+
         this.menu.connect('open-state-changed', this._onOpenStateChanged.bind(this));
         this.menu.connect('key-press-event', this._onMenuKeyPress.bind(this));
 
@@ -70,6 +64,7 @@ var GPasteIndicator = new Lang.Class({
             reactive: false,
             can_focus: false
         });
+        this._actions._ornamentLabel.set_x_expand(true);
 
         this._addToPostHeader(this._dummyHistoryItem);
         this._addToPreFooter(new PopupMenu.PopupSeparatorMenuItem());
@@ -87,9 +82,9 @@ var GPasteIndicator = new Lang.Class({
             this._addToHeader(this._searchItem);
             this._addToHeader(this._pageSwitcher);
 
-            this._actions.actor.add(this._uiItem.actor, { expand: true, x_fill: false });
-            this._actions.actor.add(this._emptyHistoryItem.actor, { expand: true, x_fill: false });
-            this._actions.actor.add(this._aboutItem.actor, { expand: true, x_fill: false });
+            this._actions.add_child(this._uiItem);
+            this._actions.add_child(this._emptyHistoryItem);
+            this._actions.add_child(this._aboutItem);
 
             this._settingsMaxSizeChangedId = this._settings.connect('changed::max-displayed-history-size', this._resetMaxDisplayedSize.bind(this));
             this._resetMaxDisplayedSize();
@@ -103,53 +98,53 @@ var GPasteIndicator = new Lang.Class({
             this.menu.actor.connect('key-press-event', this._onKeyPressEvent.bind(this));
             this.menu.actor.connect('key-release-event', this._onKeyReleaseEvent.bind(this));
 
-            this.actor.connect('destroy', this._onDestroy.bind(this));
+            this.connect('destroy', this._onDestroy.bind(this));
         });
-    },
+    }
 
-    shutdown: function() {
+    shutdown() {
         this._onStateChanged (false);
         this._onDestroy();
         this.destroy();
-    },
+    }
 
-    _onKeyPressEvent: function(actor, event) {
+    _onKeyPressEvent(actor, event) {
         if (event.has_control_modifier()) {
             const nb = parseInt(event.get_key_unicode());
             if (!isNaN(nb) && nb >= 0 && nb <= 9 && nb < this._history.length) {
-                this._history[nb].activate();
+                this._history[nb].activate(event);
             }
         } else {
             this._maybeUpdateIndexVisibility(event, true);
         }
-    },
+    }
 
-    _onKeyReleaseEvent: function(actor, event) {
+    _onKeyReleaseEvent(actor, event) {
         this._updateIndexVisibility(!this._eventIsControlKey(event) && event.has_control_modifier());
-    },
+    }
 
-    _maybeUpdateIndexVisibility: function(event, state) {
+    _maybeUpdateIndexVisibility(event, state) {
         if (this._eventIsControlKey(event)) {
             this._updateIndexVisibility(state);
         }
-    },
+    }
 
-    _updateIndexVisibility: function(state) {
+    _updateIndexVisibility(state) {
         this._history.slice(0, 10).forEach(function(i) {
             i.showIndex(state);
         });
-    },
+    }
 
-    _eventIsControlKey: function(event) {
+    _eventIsControlKey(event) {
         const key = event.get_key_symbol();
         return (key == Clutter.KEY_Control_L || key == Clutter.KEY_Control_R);
-    },
+    }
 
-    _hasSearch: function() {
+    _hasSearch() {
         return this._searchItem.text.length > 0;
-    },
+    }
 
-    _onSearch: function(page) {
+    _onSearch(page) {
         if (this._hasSearch()) {
             const search = this._searchItem.text.toLowerCase();
 
@@ -174,7 +169,7 @@ var GPasteIndicator = new Lang.Class({
                 });
 
                 /* If we had no result, updateForSize would have returned false */
-                this._dummyHistoryItem.actor.hide();
+                this._dummyHistoryItem.hide();
 
                 this._history.slice(results - offset, maxSize).forEach(function(i) {
                     i.setIndex(-1);
@@ -184,26 +179,26 @@ var GPasteIndicator = new Lang.Class({
             this._searchResults = [];
             this._refresh(0);
         }
-    },
+    }
 
-    _onNewSearch: function() {
+    _onNewSearch() {
         this._onSearch(1);
-    },
+    }
 
-    _resetElementSize: function() {
+    _resetElementSize() {
         const size = this._settings.get_element_size();
         this._searchItem.resetSize(size/2 + 3);
         this._history.forEach(function(i) {
             i.setTextSize(size);
         });
-    },
+    }
 
-    _updatePage: function(page) {
+    _updatePage(page) {
         this._pageSwitcher.setActive(page);
         this._refresh(0);
-    },
+    }
 
-    _resetMaxDisplayedSize: function() {
+    _resetMaxDisplayedSize() {
         const oldSize = this._history.length;
         const newSize = this._settings.get_max_displayed_history_size();
         const elementSize = this._settings.get_element_size();
@@ -229,9 +224,9 @@ var GPasteIndicator = new Lang.Class({
         } else {
             this._updatePage((offset / oldSize) + 1);
         }
-    },
+    }
 
-    _update: function(client, action, target, position) {
+    _update(client, action, target, position) {
         switch (target) {
         case GPaste.UpdateTarget.ALL:
             this._refresh(0);
@@ -249,9 +244,9 @@ var GPasteIndicator = new Lang.Class({
             }
             break;
         }
-    },
+    }
 
-    _refresh: function(resetTextFrom) {
+    _refresh(resetTextFrom) {
         if (this._searchResults.length > 0) {
             this._onSearch(this._pageSwitcher.getPage());
         } else if (this._hasSearch()) {
@@ -285,61 +280,61 @@ var GPasteIndicator = new Lang.Class({
                 });
             });
         }
-    },
+    }
 
-    _updateVisibility: function(empty, search) {
+    _updateVisibility(empty, search) {
         if (!empty) {
-            this._dummyHistoryItem.actor.hide();
-            this._emptyHistoryItem.actor.show();
-            this._searchItem.actor.show();
+            this._dummyHistoryItem.hide();
+            this._emptyHistoryItem.show();
+            this._searchItem.show();
         } else if (this._hasSearch()) {
             this._dummyHistoryItem.showNoResult();
-            this._emptyHistoryItem.actor.hide();
-            this._searchItem.actor.show();
+            this._emptyHistoryItem.hide();
+            this._searchItem.show();
         } else {
             this._dummyHistoryItem.showEmpty();
-            this._emptyHistoryItem.actor.hide();
-            this._searchItem.actor.hide();
+            this._emptyHistoryItem.hide();
+            this._searchItem.hide();
         }
-    },
+    }
 
-    _popup: function() {
+    _popup() {
         this.menu.open(true);
-    },
+    }
 
-    _toggle: function(c, state) {
+    _toggle(c, state) {
         this._switch.toggle(state);
-    },
+    }
 
-    _selectSearch: function() {
+    _selectSearch() {
         if (this._history.length > 0) {
             this._searchItem.grabFocus();
         }
-    },
+    }
 
-    _addToHeader: function(item) {
+    _addToHeader(item) {
         this.menu.addMenuItem(item, this._headerSize++);
-    },
+    }
 
-    _addToPostHeader: function(item) {
+    _addToPostHeader(item) {
         this.menu.addMenuItem(item, this._headerSize + this._postHeaderSize++);
-    },
+    }
 
-    _addToPreFooter: function(item) {
+    _addToPreFooter(item) {
         this.menu.addMenuItem(item, this._headerSize + this._postHeaderSize + this._history.length + this._preFooterSize++);
-    },
+    }
 
-    _addToFooter: function(item) {
+    _addToFooter(item) {
         this.menu.addMenuItem(item, this._headerSize + this._postHeaderSize + this._history.length + this._preFooterSize + this._footerSize++);
-    },
+    }
 
-    _onStateChanged: function(state) {
+    _onStateChanged(state) {
         if (this._client) {
             this._client.on_extension_state_changed(state, null);
         }
-    },
+    }
 
-    _onOpenStateChanged: function(menu, state) {
+    _onOpenStateChanged(menu, state) {
         if (state) {
             this._searchItem.reset();
             this._updatePage(1);
@@ -348,9 +343,9 @@ var GPasteIndicator = new Lang.Class({
         } else {
             this._updateIndexVisibility(false);
         }
-    },
+    }
 
-    _onMenuKeyPress: function(actor, event) {
+    _onMenuKeyPress(actor, event) {
         const symbol = event.get_key_symbol();
         if (symbol == Clutter.KEY_Left) {
             return this._pageSwitcher.previous();
@@ -359,9 +354,9 @@ var GPasteIndicator = new Lang.Class({
             return this._pageSwitcher.next();
         }
         return Clutter.EVENT_PROPAGATE;
-    },
+    }
 
-    _onDestroy: function() {
+    _onDestroy() {
         if (!this._client) {
             return;
         }
