@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2011-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #if !defined (__G_PASTE_H_INSIDE__) && !defined (G_PASTE_COMPILATION)
@@ -24,7 +11,7 @@
 #ifndef __G_PASTE_ITEM_H__
 #define __G_PASTE_ITEM_H__
 
-#include <gpaste-macros.h>
+#include <gpaste-special-atom.h>
 
 G_BEGIN_DECLS
 
@@ -33,6 +20,11 @@ typedef enum {
     G_PASTE_ITEM_STATE_ACTIVE
 } GPasteItemState;
 
+typedef struct {
+    GPasteSpecialAtom mime;
+    gchar            *data;
+} GPasteSpecialValue;
+
 #define G_PASTE_TYPE_ITEM (g_paste_item_get_type ())
 
 G_PASTE_DERIVABLE_TYPE (Item, item, ITEM, GObject)
@@ -52,19 +44,24 @@ struct _GPasteItemClass
     const gchar *(*get_kind) (const GPasteItem *self);
 };
 
-const gchar *g_paste_item_get_value          (const GPasteItem *self);
-const gchar *g_paste_item_get_real_value     (const GPasteItem *self);
-const gchar *g_paste_item_get_display_string (const GPasteItem *self);
-gboolean     g_paste_item_equals             (const GPasteItem *self,
-                                              const GPasteItem *other);
-const gchar *g_paste_item_get_kind           (const GPasteItem *self);
-guint64      g_paste_item_get_size           (const GPasteItem *self);
+const gchar  *g_paste_item_get_value          (const GPasteItem *self);
+const gchar  *g_paste_item_get_real_value     (const GPasteItem *self);
+const GSList *g_paste_item_get_special_values (const GPasteItem *self);
+const gchar  *g_paste_item_get_special_value  (const GPasteItem *self,
+                                               GPasteSpecialAtom atom);
+const gchar  *g_paste_item_get_display_string (const GPasteItem *self);
+gboolean      g_paste_item_equals             (const GPasteItem *self,
+                                               const GPasteItem *other);
+const gchar  *g_paste_item_get_kind           (const GPasteItem *self);
+guint64       g_paste_item_get_size           (const GPasteItem *self);
 
 void g_paste_item_set_state (GPasteItem     *self,
                              GPasteItemState state);
 
-void g_paste_item_set_display_string (GPasteItem  *self,
-                                      const gchar *display_string);
+void g_paste_item_set_display_string (GPasteItem               *self,
+                                      const gchar              *display_string);
+void g_paste_item_add_special_value  (GPasteItem               *self,
+                                      const GPasteSpecialValue *special_value);
 
 void g_paste_item_set_size    (GPasteItem *self,
                                guint64     size);
