@@ -1,20 +1,7 @@
 /*
- *      This file is part of GPaste.
+ * This file is part of GPaste.
  *
- *      Copyright 2014-2015 Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
- *
- *      GPaste is free software: you can redistribute it and/or modify
- *      it under the terms of the GNU General Public License as published by
- *      the Free Software Foundation, either version 3 of the License, or
- *      (at your option) any later version.
- *
- *      GPaste is distributed in the hope that it will be useful,
- *      but WITHOUT ANY WARRANTY; without even the implied warranty of
- *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *      GNU General Public License for more details.
- *
- *      You should have received a copy of the GNU General Public License
- *      along with GPaste.  If not, see <http://www.gnu.org/licenses/>.
+ * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-password-item.h>
@@ -31,7 +18,7 @@ typedef struct
     gchar *name;
 } GPastePasswordItemPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GPastePasswordItem, g_paste_password_item, G_PASTE_TYPE_TEXT_ITEM)
+G_PASTE_DEFINE_TYPE_WITH_PRIVATE (PasswordItem, password_item, G_PASTE_TYPE_TEXT_ITEM)
 
 /**
  * g_paste_password_item_get_name:
@@ -44,9 +31,9 @@ G_DEFINE_TYPE_WITH_PRIVATE (GPastePasswordItem, g_paste_password_item, G_PASTE_T
 G_PASTE_VISIBLE const gchar *
 g_paste_password_item_get_name (const GPastePasswordItem *self)
 {
-    g_return_val_if_fail (G_PASTE_IS_PASSWORD_ITEM (self), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_PASSWORD_ITEM (self), NULL);
 
-    GPastePasswordItemPrivate *priv = g_paste_password_item_get_instance_private (self);
+    const GPastePasswordItemPrivate *priv = _g_paste_password_item_get_instance_private (self);
 
     return priv->name;
 }
@@ -57,14 +44,12 @@ g_paste_password_item_get_name (const GPastePasswordItem *self)
  * @name: (nullable): the new name
  *
  * Set the name of the given item
- *
- * Returns:
  */
 G_PASTE_VISIBLE void
 g_paste_password_item_set_name (GPastePasswordItem *self,
                                 const gchar        *name)
 {
-    g_return_if_fail (G_PASTE_IS_PASSWORD_ITEM (self));
+    g_return_if_fail (_G_PASTE_IS_PASSWORD_ITEM (self));
     g_return_if_fail (!name || g_utf8_validate (name, -1, NULL));
 
     GPastePasswordItemPrivate *priv = g_paste_password_item_get_instance_private (self);
@@ -99,8 +84,8 @@ static gboolean
 g_paste_password_item_equals (const GPasteItem *self,
                               const GPasteItem *other)
 {
-    g_return_val_if_fail (G_PASTE_IS_PASSWORD_ITEM (self), FALSE);
-    g_return_val_if_fail (G_PASTE_IS_ITEM (other), FALSE);
+    g_return_val_if_fail (_G_PASTE_IS_PASSWORD_ITEM (self), FALSE);
+    g_return_val_if_fail (_G_PASTE_IS_ITEM (other), FALSE);
 
     /* Passwords are never considered equals, except when it's the exact same object */
     return FALSE;
@@ -109,7 +94,7 @@ g_paste_password_item_equals (const GPasteItem *self,
 static void
 g_paste_password_item_finalize (GObject *object)
 {
-    GPastePasswordItemPrivate *priv = g_paste_password_item_get_instance_private (G_PASTE_PASSWORD_ITEM (object));
+    const GPastePasswordItemPrivate *priv = _g_paste_password_item_get_instance_private (G_PASTE_PASSWORD_ITEM (object));
 
     g_free (priv->name);
 
@@ -130,11 +115,8 @@ g_paste_password_item_class_init (GPastePasswordItemClass *klass)
 }
 
 static void
-g_paste_password_item_init (GPastePasswordItem *self )
+g_paste_password_item_init (GPastePasswordItem *self G_GNUC_UNUSED)
 {
-    GPastePasswordItemPrivate *priv = g_paste_password_item_get_instance_private (self);
-
-    priv->name = NULL;
 }
 
 /**
