@@ -1,13 +1,15 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-ui-backup-history.h>
 #include <gpaste-ui-history-actions.h>
 #include <gpaste-util.h>
 
+#include "gpaste-gtk-compat.h"
+
 struct _GPasteUiBackupHistory
 {
     GPasteUiHistoryAction parent_instance;
@@ -48,13 +50,18 @@ g_paste_ui_backup_history_confirm_dialog (GtkWindow   *parent,
     GtkWidget *vbox = gtk_dialog_get_content_area (d);
     GtkBox *box = GTK_BOX (vbox);
 
-    gtk_widget_set_margin_start (vbox, 10);
-    gtk_widget_set_margin_end (vbox, 10);
+    gtk_widget_set_margin_start (vbox, 2);
+    gtk_widget_set_margin_end (vbox, 2);
+    gtk_widget_set_margin_bottom (vbox, 2);
 
-    gtk_box_pack_start (box, label, TRUE, TRUE, 5);
+    gtk_widget_set_vexpand (label, TRUE);
+    gtk_widget_set_valign (label, TRUE);
+    gtk_box_pack_start (box, label, TRUE, TRUE);
     gtk_widget_show (label);
 
-    gtk_box_pack_start (box, entry, TRUE, TRUE, 5);
+    gtk_widget_set_vexpand (entry, TRUE);
+    gtk_widget_set_valign (entry, TRUE);
+    gtk_box_pack_start (box, entry, TRUE, TRUE);
     gtk_entry_set_text (e, default_name);
     gtk_widget_show (entry);
 
@@ -84,6 +91,7 @@ g_paste_ui_backup_history_confirm_dialog (GtkWindow   *parent,
 static gboolean
 g_paste_ui_backup_history_activate (GPasteUiHistoryAction *self G_GNUC_UNUSED,
                                     GPasteClient          *client,
+                                    GPasteSettings        *settings G_GNUC_UNUSED,
                                     GtkWindow             *rootwin,
                                     const gchar           *history)
 {
@@ -109,6 +117,7 @@ g_paste_ui_backup_history_init (GPasteUiBackupHistory *self G_GNUC_UNUSED)
 /**
  * g_paste_ui_backup_history_new:
  * @client: a #GPasteClient
+ * @settings: a #GPasteSettings
  * @actions: the #GPasteUiHistoryActions
  * @rootwin: the root #GtkWindow
  *
@@ -118,13 +127,15 @@ g_paste_ui_backup_history_init (GPasteUiBackupHistory *self G_GNUC_UNUSED)
  *          free it with g_object_unref
  */
 G_PASTE_VISIBLE GtkWidget *
-g_paste_ui_backup_history_new (GPasteClient *client,
-                               GtkWidget    *actions,
-                               GtkWindow    *rootwin)
+g_paste_ui_backup_history_new (GPasteClient   *client,
+                               GPasteSettings *settings,
+                               GtkWidget      *actions,
+                               GtkWindow      *rootwin)
 {
     g_return_val_if_fail (_G_PASTE_IS_CLIENT (client), NULL);
+    g_return_val_if_fail (_G_PASTE_IS_SETTINGS (settings), NULL);
     g_return_val_if_fail (_G_PASTE_IS_UI_HISTORY_ACTIONS (actions), NULL);
     g_return_val_if_fail (GTK_IS_WINDOW (rootwin), NULL);
 
-    return g_paste_ui_history_action_new (G_PASTE_TYPE_UI_BACKUP_HISTORY, client, actions, rootwin, _("Backup"));
+    return g_paste_ui_history_action_new (G_PASTE_TYPE_UI_BACKUP_HISTORY, client, settings, actions, rootwin, _("Backup"));
 }
