@@ -1,7 +1,7 @@
 /*
  * This file is part of GPaste.
  *
- * Copyright (c) 2010-2016, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
+ * Copyright (c) 2010-2018, Marc-Antoine Perennou <Marc-Antoine@Perennou.com>
  */
 
 #include <gpaste-ui-item.h>
@@ -15,6 +15,9 @@ struct _GPasteUiItem
 typedef struct
 {
     GPasteClient   *client;
+    GPasteSettings *settings;
+
+    GtkWindow      *rootwin;
 
     guint64         index;
     gboolean        bold;
@@ -28,16 +31,26 @@ G_PASTE_DEFINE_TYPE_WITH_PRIVATE (UiItem, ui_item, G_PASTE_TYPE_UI_ITEM_SKELETON
  * g_paste_ui_item_activate:
  * @self: a #GPasteUiItem instance
  *
- * Refresh the item
+ * Activate/Select the item
+ *
+ * returns: whether there was anything to select or not
  */
-G_PASTE_VISIBLE void
+G_PASTE_VISIBLE gboolean
 g_paste_ui_item_activate (GPasteUiItem *self)
 {
-    g_return_if_fail (_G_PASTE_IS_UI_ITEM (self));
+    g_return_val_if_fail (_G_PASTE_IS_UI_ITEM (self), FALSE);
 
     const GPasteUiItemPrivate *priv = _g_paste_ui_item_get_instance_private (self);
 
+    if (priv->index == (guint64) -1)
+        return FALSE;
+
     g_paste_client_select (priv->client, priv->index, NULL, NULL);
+
+    if (g_paste_settings_get_close_on_select (priv->settings))
+        gtk_window_close (priv->rootwin); /* Exit the application */
+
+    return TRUE;
 }
 
 /**
@@ -150,9 +163,10 @@ g_paste_ui_item_set_index (GPasteUiItem *self,
 static void
 g_paste_ui_item_dispose (GObject *object)
 {
-    const GPasteUiItemPrivate *priv = _g_paste_ui_item_get_instance_private (G_PASTE_UI_ITEM (object));
+    GPasteUiItemPrivate *priv = g_paste_ui_item_get_instance_private (G_PASTE_UI_ITEM (object));
 
     g_clear_object (&priv->client);
+    g_clear_object (&priv->settings);
 
     G_OBJECT_CLASS (g_paste_ui_item_parent_class)->dispose (object);
 }
@@ -197,6 +211,8 @@ g_paste_ui_item_new (GPasteClient   *client,
     GPasteUiItemPrivate *priv = g_paste_ui_item_get_instance_private (G_PASTE_UI_ITEM (self));
 
     priv->client = g_object_ref (client);
+    priv->settings = g_object_ref (settings);
+    priv->rootwin = rootwin;
 
     g_paste_ui_item_set_index (G_PASTE_UI_ITEM (self), index);
 
